﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

using System.Xml.Linq;
using System.Windows.Media.Imaging;

namespace myBookFinder
{
    public class PhotoList
    {
        public string descr { get; set; }
        public string path { get; set; }
    }

    public partial class Page : UserControl
    {
        const string c_AmazonURL = "http://webservices.amazon.com/onca/xml?Service=AWSECommerceService"
                    + "&Keywords={0}"
                    + "&AWSAccessKeyId={1}"
                    + "&Operation=ItemSearch"
                    + "&SearchIndex=Books"
                    + "&ResponseGroup=Large";

        XNamespace ns = "http://webservices.amazon.com/AWSECommerceService/2005-10-05";

        private List<PhotoList> myPhotos = new List<PhotoList>();
        int nIndex = -1;


        public Page()
        {
            InitializeComponent();

            btnSearch.Click += new RoutedEventHandler(GetPhotos);

            photo1.MouseLeftButtonDown += new MouseButtonEventHandler(PhotoSwap);
            photo2.MouseLeftButtonDown += new MouseButtonEventHandler(PhotoSwap);

            myListBox.SelectionChanged += new SelectionChangedEventHandler(myListBox_SelectionChanged);
        }

        void myListBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            nIndex = myListBox.SelectedIndex - 1;
            PhotoSwap(sender, null);
        }

        void GetPhotos(object sender, RoutedEventArgs e)
        {
            txtTitle.Text = "Getting Photos: " + myTextBox.Text;
            string requestURL = string.Format(c_AmazonURL, 
                myTextBox.Text, "[INSERT AMAZON KEY - http://aws.amazon.com]");
            WebClient myClient = new WebClient();

            myClient.DownloadStringCompleted += new DownloadStringCompletedEventHandler(ParseImages);
            myClient.DownloadStringAsync(new Uri(requestURL));

        }

        void ParseImages(object sender, DownloadStringCompletedEventArgs e)
        {
            try
            {
                if (e.Error == null)
                {
                    XElement myXML = XElement.Parse(e.Result);

                    var books = from root in myXML.Descendants(ns + "Item")
                                let attributes = root.Element(ns + "ItemAttributes")
                                where (string)root.Element(ns + "MediumImage") != null
                                select new PhotoList
                                {
                                    path = (string)root.Element(ns + "MediumImage").Element(ns + "URL").Value,
                                    descr = (string)attributes.Element(ns + "Title").Value
                                };

                    myPhotos.Clear();
                    myPhotos = books.ToList();
                    txtTitle.Text = "Click to Flip";

                    myListBox.ItemsSource = myPhotos;

                    PhotoSwap(sender, null);

                }
            }
            catch (Exception ex)
            {
                txtTitle.Text = ex.Message;
            }
        }


        void PhotoSwap(object sender, MouseButtonEventArgs e)
        {
            int nNext = nIndex + 1;

            if (nNext >= myPhotos.Count)
                nNext = 0;
            if (myPhotos.Count < 1)
                return;

            BitmapImage bmi1 = (BitmapImage)photo2img.ImageSource;
            photo1img.ImageSource = new BitmapImage(bmi1.UriSource);

            photo1.Opacity = 1;
            photo2.Opacity = 0;

            BitmapImage bmi2 = new BitmapImage(new Uri(myPhotos[nNext].path, UriKind.RelativeOrAbsolute));

            photo2img.ImageSource = new BitmapImage(bmi2.UriSource);

            txtTitle.Text = nNext.ToString() + ". " + myPhotos[nNext].descr;
            nIndex = nNext;

            swapPhoto.Begin();

        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("Hello World");
        }
    }
}
